@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.27 2003/12/09 22:23:05 marco Exp $
+ *  $Id: ephy-embed.c,v 1.29 2004/01/04 12:52:04 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +28,7 @@
 #include "mozilla-embed-single.h"
 #include "mozilla-embed.h"
 
-static void ephy_embed_base_init (gpointer base_class);
+static void ephy_embed_base_init (gpointer g_class);
 
 GType
 ephy_embed_get_type (void)
@@ -39,7 +39,7 @@ ephy_embed_get_type (void)
 	{
 		static const GTypeInfo our_info =
 		{
-			sizeof (EphyEmbedClass),
+			sizeof (EphyEmbedIFace),
 			ephy_embed_base_init,
 			NULL,
 		};
@@ -63,7 +63,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_new_window",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, new_window),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, new_window),
 			      NULL, NULL,
 			      ephy_marshal_VOID__POINTER_INT,
 			      G_TYPE_NONE,
@@ -73,7 +73,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_context_menu",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, context_menu),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, context_menu),
 			      g_signal_accumulator_true_handled, NULL,
 			      ephy_marshal_BOOLEAN__OBJECT,
 			      G_TYPE_BOOLEAN,
@@ -82,7 +82,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_favicon",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, favicon),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, favicon),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
@@ -91,7 +91,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_location",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, location),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, location),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
@@ -100,7 +100,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_net_state",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, net_state),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, net_state),
 			      NULL, NULL,
 			      ephy_marshal_VOID__STRING_INT,
 			      G_TYPE_NONE,
@@ -110,7 +110,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_dom_mouse_click",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, dom_mouse_click),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, dom_mouse_click),
 			      g_signal_accumulator_true_handled, NULL,
 			      ephy_marshal_BOOLEAN__OBJECT,
 			      G_TYPE_BOOLEAN,
@@ -119,7 +119,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_dom_mouse_down",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, dom_mouse_down),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, dom_mouse_down),
 			      g_signal_accumulator_true_handled, NULL,
 			      ephy_marshal_BOOLEAN__OBJECT,
 			      G_TYPE_BOOLEAN,
@@ -128,7 +128,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_popup_blocked",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, popup_blocked),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, popup_blocked),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
@@ -136,7 +136,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_security_change",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, security_change),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, security_change),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE,
@@ -145,12 +145,13 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_zoom_change",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, zoom_change),
+			      G_STRUCT_OFFSET (EphyEmbedIFace, zoom_change),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__FLOAT,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_FLOAT);
+
 		initialized = TRUE;
 	}
 }
@@ -159,102 +160,102 @@ void
 ephy_embed_load_url (EphyEmbed *embed,
 		     const char *url)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->load_url (embed, url);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->load_url (embed, url);
 }
 
 void
 ephy_embed_stop_load (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->stop_load (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->stop_load (embed);
 }
 
 gboolean
 ephy_embed_can_go_back (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->can_go_back (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->can_go_back (embed);
 }
 
 gboolean
 ephy_embed_can_go_forward (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->can_go_forward (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->can_go_forward (embed);
 }
 
 gboolean
 ephy_embed_can_go_up (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->can_go_up (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->can_go_up (embed);
 }
 
 GSList *
 ephy_embed_get_go_up_list (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_go_up_list (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_go_up_list (embed);
 }
 
 void
 ephy_embed_go_back (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->go_back (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->go_back (embed);
 }
 
 void
 ephy_embed_go_forward (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->go_forward (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->go_forward (embed);
 }
 
 void
 ephy_embed_go_up (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->go_up (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->go_up (embed);
 }
 
 
 char *
 ephy_embed_get_title (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_title (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_title (embed);
 }
 
 char *
 ephy_embed_get_location (EphyEmbed *embed,
 			 gboolean toplevel)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_location (embed, toplevel);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_location (embed, toplevel);
 }
 
 char *
 ephy_embed_get_link_message (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_link_message (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_link_message (embed);
 }
 
 char *
 ephy_embed_get_js_status (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_js_status (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_js_status (embed);
 }
 
 void
 ephy_embed_reload (EphyEmbed *embed,
 		   EmbedReloadFlags flags)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->reload (embed, flags);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->reload (embed, flags);
 }
 
 void
@@ -262,22 +263,22 @@ ephy_embed_zoom_set (EphyEmbed *embed,
 		     float zoom,
 		     gboolean reflow)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->zoom_set (embed, zoom, reflow);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->zoom_set (embed, zoom, reflow);
 }
 
 float
 ephy_embed_zoom_get (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->zoom_get (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->zoom_get (embed);
 }
 
 int
 ephy_embed_shistory_n_items  (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->shistory_n_items (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->shistory_n_items (embed);
 }
 
 void
@@ -287,23 +288,23 @@ ephy_embed_shistory_get_nth (EphyEmbed *embed,
 			     char **url,
 			     char **title)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->shistory_get_nth (embed, nth, is_relative, url, title);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->shistory_get_nth (embed, nth, is_relative, url, title);
 }
 
 int
 ephy_embed_shistory_get_pos (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->shistory_get_pos (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->shistory_get_pos (embed);
 }
 
 void
 ephy_embed_shistory_go_nth (EphyEmbed *embed,
 			    int nth)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->shistory_go_nth (embed, nth);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->shistory_go_nth (embed, nth);
 }
 
 void
@@ -311,8 +312,8 @@ ephy_embed_get_security_level (EphyEmbed *embed,
 			       EmbedSecurityLevel *level,
 			       char **description)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->get_security_level (embed, level, description);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->get_security_level (embed, level, description);
 }
 
 void
@@ -321,60 +322,60 @@ ephy_embed_find_set_properties  (EphyEmbed *embed,
 				 gboolean case_sensitive,
 				 gboolean match_word)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->find_set_properties (embed, search_string, case_sensitive, match_word);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->find_set_properties (embed, search_string, case_sensitive, match_word);
 }
 
 gboolean
 ephy_embed_find_next (EphyEmbed *embed,
 		      gboolean backwards)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->find_next (embed, backwards);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->find_next (embed, backwards);
 }
 
 void
 ephy_embed_activate (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->activate (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->activate (embed);
 }
 
 void
 ephy_embed_set_encoding (EphyEmbed *embed,
 			 const char *encoding)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->set_encoding (embed, encoding);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->set_encoding (embed, encoding);
 }
 
 EphyEncodingInfo *
 ephy_embed_get_encoding_info (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_encoding_info (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_encoding_info (embed);
 }
 
 void
 ephy_embed_print (EphyEmbed *embed,
 		  EmbedPrintInfo *info)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->print (embed, info);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->print (embed, info);
 }
 
 void
 ephy_embed_print_preview_close (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->print_preview_close (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->print_preview_close (embed);
 }
 
 int
 ephy_embed_print_preview_n_pages (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->print_preview_n_pages (embed);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->print_preview_n_pages (embed);
 }
 
 void
@@ -382,6 +383,13 @@ ephy_embed_print_preview_navigate (EphyEmbed *embed,
 				   EmbedPrintPreviewNavType type,
 				   int page)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->print_preview_navigate (embed, type, page);
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->print_preview_navigate (embed, type, page);
+}
+
+gboolean
+ephy_embed_has_modified_forms (EphyEmbed *embed)
+{
+	EphyEmbedIFace *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->has_modified_forms (embed);
 }
