@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.18 2004/01/27 12:48:55 marco Exp $
+ *  $Id: EphyBrowser.cpp,v 1.20 2004/02/12 19:30:48 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -463,10 +463,16 @@ nsresult EphyBrowser::SetZoomOnDocshell (float aZoom, nsIDocShell *DocShell)
 	nsCOMPtr<nsIPresContext> PresContext;
 	DocShell->GetPresContext (getter_AddRefs(PresContext));
 	NS_ENSURE_TRUE (PresContext, NS_ERROR_FAILURE);
-					
+
+#if MOZILLA_SNAPSHOT > 13
+	nsIDeviceContext *DeviceContext;
+	DeviceContext = PresContext->DeviceContext();
+	NS_ENSURE_TRUE (DeviceContext, NS_ERROR_FAILURE);
+#else				
 	nsCOMPtr<nsIDeviceContext> DeviceContext;
 	PresContext->GetDeviceContext (getter_AddRefs(DeviceContext));
 	NS_ENSURE_TRUE (DeviceContext, NS_ERROR_FAILURE);
+#endif
 
 	return DeviceContext->SetTextZoom (aZoom);
 }
