@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.21 2004/01/29 11:43:27 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.24 2004/02/12 20:08:25 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -540,46 +540,80 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 static char*
 GetFilePath (const char *filename)
 {
-	char *path, *download_dir, *expanded, *tmp;
+	char *path = NULL;
+	char *download_dir, *converted_dp, *expanded, *tmp;
 
 	download_dir = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
 
 	if (!download_dir)
 	{
 		/* Emergency download destination */
-		download_dir = g_strdup (g_get_home_dir ());
+		return g_build_filename (g_get_home_dir (), filename, NULL);
 	}
-	else if (g_utf8_collate (download_dir, "Downloads") == 0)
+
+	if (g_utf8_collate (download_dir, "Downloads") == 0)
 	{
-		tmp = ephy_file_downloads_dir ();
 		g_free (download_dir);
-		download_dir = tmp;
+
+		return g_build_filename (ephy_file_downloads_dir (),
+					 filename, NULL);
 	}
 
-	expanded = gnome_vfs_expand_initial_tilde (download_dir);
-	path = g_build_filename (expanded, filename, NULL);
-	g_free (expanded);
-
+	converted_dp = g_filename_from_utf8 (download_dir, -1, NULL, NULL, NULL);
 	g_free (download_dir);
 
+	if (converted_dp)
+	{
+		expanded = gnome_vfs_expand_initial_tilde (converted_dp);
+		path = g_build_filename (expanded, filename, NULL);
+
+		g_free (expanded);
+		g_free (converted_dp);
+	}
+	else
+	{
+		/* Fallback, see FIXME above too */
+		path = g_build_filename (g_get_home_dir (), filename, NULL);
+	}
+
 	return path;
 }
 
 nsresult BuildDownloadPath (const char *defaultFileName, nsILocalFile **_retval)
 {
 	char *path;
-	int i = 0;
 
 	path = GetFilePath (defaultFileName);
 	
-	while (g_file_test (path, G_FILE_TEST_EXISTS))
+	if (g_file_test (path, G_FILE_TEST_EXISTS))
 	{
-		g_free (path);
+		int i = 1;
+		char *dot_pos, *serial = NULL;
+		GString *tmp_path;
+		gssize position;
 
-		char *tmp_path;
-		tmp_path = g_strdup_printf ("%s.%d", defaultFileName,  ++i);
-		path = GetFilePath (tmp_path);
-		g_free (tmp_path);
+		dot_pos = g_strrstr (defaultFileName, ".");
+		if (dot_pos)
+		{
+			position = dot_pos - defaultFileName;
+		}
+		else
+		{
+			position = strlen (defaultFileName);
+		}
+		tmp_path = g_string_new (NULL);
+
+		do {
+			g_free (path);
+			g_string_assign (tmp_path, defaultFileName);
+			serial = g_strdup_printf ("(%d)", i++);
+			g_string_insert (tmp_path, position, serial);
+			g_free (serial);
+			path = GetFilePath (tmp_path->str);
+			
+		} while (g_file_test (path, G_FILE_TEST_EXISTS));
+		
+		g_string_free (tmp_path, TRUE);
 	}
 
 	nsCOMPtr <nsILocalFile> destFile (do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
