@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.29 2004/01/25 22:48:28 marco Exp $
+ *  $Id: ephy-dialog.c,v 1.30 2004/02/12 20:15:18 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -157,6 +157,10 @@ set_sensitivity (PropertyInfo *info, gboolean sensitive)
 			gtk_widget_set_sensitive (GTK_WIDGET (l->data), sensitive);
 		}
 	}
+	else if (info->widget_type == PT_EDITABLE)
+	{
+		gtk_editable_set_editable (GTK_EDITABLE (info->widget), sensitive);
+	}
 	else
 	{
 		gtk_widget_set_sensitive (info->widget, sensitive);
