@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-chooser.c,v 1.4 2003/11/30 14:10:15 chpe Exp $
+ *  $Id: ephy-file-chooser.c,v 1.7 2004/02/12 19:13:53 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,6 +24,7 @@
 #endif
 
 #include "ephy-file-chooser.h"
+#include "ephy-file-helpers.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-state.h"
 #include "ephy-debug.h"
@@ -52,9 +53,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_file_chooser_get_type (void)
 {
-	static GType ephy_file_chooser_type = 0;
+	static GType type = 0;
 
-	if (ephy_file_chooser_type == 0)
+	if (type == 0)
 	{
 		static const GTypeInfo our_info =
 		{
@@ -69,32 +70,26 @@ ephy_file_chooser_get_type (void)
 			(GInstanceInitFunc) ephy_file_chooser_init
 		};
 
-		ephy_file_chooser_type = g_type_register_static (GTK_TYPE_FILE_CHOOSER_DIALOG,
-								 "EphyFileChooser",
-								 &our_info, 0);
+		type = g_type_register_static (GTK_TYPE_FILE_CHOOSER_DIALOG,
+					       "EphyFileChooser",
+					       &our_info, 0);
 	}
 
-	return ephy_file_chooser_type;
+	return type;
 }
 
 static void
 current_folder_changed_cb (GtkFileChooser *chooser, EphyFileChooser *dialog)
 {
-	if (dialog->priv->persist_key)
+	if (dialog->priv->persist_key != NULL)
 	{
-		char *dir, *converted;
+		char *dir;
 
 		dir = gtk_file_chooser_get_current_folder (chooser);
 
-		if (dir != NULL)
-		{
-			converted = g_filename_to_utf8 (dir, -1, NULL, NULL, NULL);
+		eel_gconf_set_path (dialog->priv->persist_key, dir);
 
-			eel_gconf_set_string (dialog->priv->persist_key, dir);
-
-			g_free (converted);
-			g_free (dir);
-		}
+		g_free (dir);
 	}
 }
 
@@ -138,22 +133,22 @@ ephy_file_chooser_set_persist_key (EphyFileChooser *dialog, const char *key)
 		converted = g_filename_from_utf8
 			(dir, -1, NULL, NULL, NULL);
 
-		expanded = gnome_vfs_expand_initial_tilde (converted);
-
-		if (expanded != NULL)
+		if (converted != NULL)
 		{
+			expanded = gnome_vfs_expand_initial_tilde (converted);
+
 			gtk_file_chooser_set_current_folder
 				(GTK_FILE_CHOOSER (dialog), expanded);
+
+			g_free (expanded);
+			g_free (converted);
 		}
 
-		g_free (expanded);
-		g_free (converted);
 		g_free (dir);
 	}
 
 	g_signal_connect (dialog, "current-folder-changed",
 			  G_CALLBACK (current_folder_changed_cb), dialog);
-
 }
 
 const char *
@@ -265,6 +260,8 @@ ephy_file_chooser_new (const char *title,
 	{
 		gtk_window_set_transient_for (GTK_WINDOW (dialog),
 					      GTK_WINDOW (parent));
+
+		gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	}
 
 	return dialog;
