@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.15 2004/01/27 13:52:44 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.16 2004/02/12 19:13:53 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -66,12 +66,18 @@ char *
 ephy_file_downloads_dir (void)
 {
 	const char *translated_folder;
+	char *converted, *downloads_dir;
 
 	/* The name of the default downloads folder */
 	translated_folder = _("Downloads");
 
-	return g_build_filename (g_get_home_dir (), "Desktop",
-				 translated_folder, NULL);
+	converted = g_filename_from_utf8 (translated_folder, -1, NULL, 
+					  NULL, NULL);
+	downloads_dir = g_build_filename (g_get_home_dir (), "Desktop",
+					  converted, NULL);
+	g_free (converted);
+
+	return downloads_dir;
 }
 
 char *
