@@ -14,10 +14,12 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-bookmark-action.c,v 1.27 2004/02/11 14:38:55 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <glib/gi18n.h>
@@ -31,7 +33,7 @@
 #include "ephy-string.h"
 #include "ephy-debug.h"
 
-#define MAX_LABEL_LENGTH 30
+#define MAX_LABEL_LENGTH 32
 
 static void ephy_bookmark_action_init       (EphyBookmarkAction *action);
 static void ephy_bookmark_action_class_init (EphyBookmarkActionClass *class);
@@ -50,6 +52,7 @@ enum
 {
 	PROP_0,
 	PROP_BOOKMARK_ID,
+	PROP_TOOLTIP,
 	PROP_LOCATION,
 	PROP_SMART_URL,
 	PROP_ICON
@@ -70,7 +73,7 @@ ephy_bookmark_action_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type)
+	if (type == 0)
 	{
 		static const GTypeInfo type_info =
 		{
@@ -297,29 +300,6 @@ activate_cb (GtkWidget *widget, GtkAction *action)
 	g_free (text);
 }
 
-static gboolean
-create_menu_proxy (GtkToolItem *item, GtkAction *action)
-{
-	EphyBookmarkAction *bm_action = EPHY_BOOKMARK_ACTION (action);
-	GtkWidget *menu_item;
-	char *menu_id;
-
-	LOG ("create_menu_proxy item %p, action %p", item, action);
-
-	menu_item = GTK_ACTION_GET_CLASS (action)->create_menu_item (action);
-
-	GTK_ACTION_GET_CLASS (action)->connect_proxy (action, menu_item);
-
-	menu_id = g_strdup_printf ("ephy-bookmark-action-%d-menu-id",
-				   bm_action->priv->bookmark_id);
-
-	gtk_tool_item_set_proxy_menu_item (item, menu_id, menu_item);
-
-	g_free (menu_id);
-
-	return TRUE;	
-}
-
 static void
 connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
@@ -348,8 +328,6 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 
 		entry = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "entry"));
 		g_signal_connect (entry, "activate", G_CALLBACK (activate_cb), action);
-
-		g_signal_connect (proxy, "create_menu_proxy", G_CALLBACK (create_menu_proxy), action);
 	}
 	else if (GTK_IS_MENU_ITEM (proxy))
 	{
@@ -372,6 +350,7 @@ ephy_bookmark_action_set_property (GObject *object,
 		case PROP_BOOKMARK_ID:
 			bmk->priv->bookmark_id = g_value_get_int (value);
 			break;
+		case PROP_TOOLTIP:
 		case PROP_LOCATION:
 			g_free (bmk->priv->location);
 			bmk->priv->location = g_strdup (g_value_get_string (value));
@@ -382,7 +361,7 @@ ephy_bookmark_action_set_property (GObject *object,
 			break;
 		case PROP_ICON:
 			g_free (bmk->priv->icon);
-			bmk->priv->icon = g_strdup (g_value_get_string (value));
+			bmk->priv->icon = g_value_dup_string (value);
 			g_object_notify (object, "icon");
 			break;
 	}
@@ -403,6 +382,16 @@ ephy_bookmark_action_get_property (GObject *object,
 		case PROP_BOOKMARK_ID:
 			g_value_set_boolean (value, bmk->priv->bookmark_id);
 			break;
+		case PROP_TOOLTIP:
+		case PROP_LOCATION:
+			g_value_set_string (value, bmk->priv->location);
+			break;
+		case PROP_SMART_URL:
+			g_value_set_boolean (value, bmk->priv->smart_url);
+			break;
+		case PROP_ICON:
+			g_value_set_string (value, bmk->priv->icon);
+			break;
 	}
 }
 
@@ -456,6 +445,13 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 							   G_MAXINT,
                                                            0,
                                                            G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+                                         PROP_LOCATION,
+                                         g_param_spec_string  ("tooltip",
+                                                               "Tooltip",
+                                                               "Tooltip",
+                                                               NULL,
+                                                               G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
                                          PROP_LOCATION,
                                          g_param_spec_string  ("location",
@@ -513,7 +509,10 @@ sync_bookmark_properties (GtkAction *action, EphyNode *bmk)
 }
 
 static void
-bookmarks_child_changed_cb (EphyNode *node, EphyNode *child, GtkAction *action)
+bookmarks_child_changed_cb (EphyNode *node,
+			    EphyNode *child,
+			    guint property_id,
+			    GtkAction *action)
 {
 	gulong id;
 
