@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.127 2003/12/16 17:29:42 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.128 2004/01/25 20:06:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1184,8 +1184,6 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 		 G_CALLBACK (keyword_node_selected_cb),
 		 editor);
 
-	search_text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-
 	ephy_node_filter_empty (editor->priv->bookmarks_filter);
 	ephy_node_filter_add_expression (editor->priv->bookmarks_filter,
 				         ephy_node_filter_expression_new (EPHY_NODE_FILTER_EXPRESSION_STRING_PROP_CONTAINS,
@@ -1337,6 +1335,7 @@ get_details_value (EphyBookmarksEditor *editor)
 		value = VIEW_TITLE;
 	}
 
+	g_slist_foreach (svalues, (GFunc) g_free, NULL);
 	g_slist_free (svalues);
 
 	return value;
