@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-completion-model.c,v 1.8 2003/12/29 21:05:07 chpe Exp $
+ *  $Id: ephy-completion-model.c,v 1.11 2004/02/11 14:38:28 marco Exp $
  */
 
 #include <config.h>
@@ -193,6 +193,7 @@ root_child_added_cb (EphyNode *node,
 static void
 root_child_changed_cb (EphyNode *node,
 		       EphyNode *child,
+		       guint property_id,
 		       EphyCompletionModel *model)
 {
 	GtkTreePath *path;
@@ -289,7 +290,7 @@ init_text_col (GValue *value, EphyNode *node, int group)
 	{
 		case BOOKMARKS_GROUP:
 			text = ephy_node_get_property_string
-				(node, EPHY_NODE_BMK_PROP_LOCATION);
+				(node, EPHY_NODE_BMK_PROP_TITLE);
 			break;
 		case HISTORY_GROUP:
 			text = ephy_node_get_property_string
@@ -346,23 +347,58 @@ init_keywords_col (GValue *value, EphyNode *node, int group)
 	g_value_set_string (value, text);
 }
 
+static gboolean
+is_base_address (const char *address)
+{
+	int slashes = 0;
+
+	if (address == NULL) return FALSE;
+
+	while (*address != '\0')
+	{
+		if (*address == '/') slashes++;
+
+		/* Base uris has 3 slashes like http://www.gnome.org/ */
+		if (slashes == 4) return FALSE;
+
+		address++;
+	}
+
+	return TRUE;
+}
+
 static void
 init_relevance_col (GValue *value, EphyNode *node, int group)
 {
-	int relevance, visits;
+	int relevance = 0;
 
-	switch (group)
+	/* We have three ordered groups: history's base
+	   addresses, bookmarks, deep history addresses */
+
+	if (group == BOOKMARKS_GROUP)
 	{
-		case HISTORY_GROUP:
-			visits = ephy_node_get_property_int
-				(node, EPHY_NODE_PAGE_PROP_VISITS);
+		relevance = 1 << 5;
+	}
+	else if (group == HISTORY_GROUP)
+	{
+		const char *address;
+		int visits;
+	
+		visits = ephy_node_get_property_int
+			(node, EPHY_NODE_PAGE_PROP_VISITS);
+		address = ephy_node_get_property_string
+			(node, EPHY_NODE_PAGE_PROP_LOCATION);
+
+		visits = MAX (visits, (1 << 5) - 1);
+
+		if (is_base_address (address))
+		{
+			relevance = visits << 10;
+		}
+		else
+		{
 			relevance = visits;
-			break;
-		case BOOKMARKS_GROUP:
-			relevance = 2000;
-			break;
-		default:
-			relevance = 0;
+		}
 	}
 	
 	g_value_set_int (value, relevance);
