@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.86 2004/01/31 03:16:29 adamh Exp $
+ *  $Id: ephy-tab.c,v 1.89 2004/02/11 16:10:06 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,7 @@
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtkradioaction.h>
+#include <gtk/gtkclipboard.h>
 #include <string.h>
 
 #define EPHY_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TAB, EphyTabPrivate))
@@ -957,7 +958,7 @@ ephy_tab_size_to_cb (EphyEmbed *embed, gint width, gint height,
 	}
 }
 
-static void
+static gboolean
 open_link_in_new_tab (EphyTab *tab,
 		      const char *link_address)
 {
@@ -965,7 +966,7 @@ open_link_in_new_tab (EphyTab *tab,
 	gboolean new_tab;
 
 	window = ephy_tab_get_window (tab);
-	g_return_if_fail (window != NULL);
+	g_return_val_if_fail (window != NULL, FALSE);
 
 	new_tab = address_has_web_scheme (link_address);
 
@@ -976,10 +977,8 @@ open_link_in_new_tab (EphyTab *tab,
 				    EPHY_NEW_TAB_OPEN_PAGE |
 				    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 	}
-	else
-	{
-		ephy_window_load_url (window, link_address);
-	}
+
+	return new_tab;
 }
 
 static void
@@ -1008,6 +1007,27 @@ save_property_url (EphyEmbed *embed,
 	g_object_unref (G_OBJECT(persist));
 }
 
+static void
+clipboard_text_received_cb (GtkClipboard *clipboard,
+			    const char *text,
+			    gpointer *weak_ptr)
+{
+	if (*weak_ptr != NULL && text != NULL)
+	{
+		EphyTab *tab = (EphyTab *) *weak_ptr;
+		EphyEmbed *embed = ephy_tab_get_embed (tab);
+
+		ephy_embed_load_url (embed, text);
+	}
+
+	if (*weak_ptr != NULL)
+	{
+		g_object_remove_weak_pointer (G_OBJECT (*weak_ptr), weak_ptr);
+	}
+
+	g_free (weak_ptr);
+}
+
 static gboolean
 ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 			     EphyEmbedEvent *event,
@@ -1059,7 +1079,7 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 
 		ephy_embed_event_get_property (event, "link", &value);
 		link_address = g_value_get_string (value);
-		open_link_in_new_tab (tab, link_address);
+		handled = open_link_in_new_tab (tab, link_address);
 	}
 	/* shift+click saves the link target */
 	else if (is_link && is_left_click && with_shift)
@@ -1076,10 +1096,22 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 	/* middle click opens the selection url */
 	else if (is_middle_clickable && is_middle_click && middle_click_opens)
 	{
-		gtk_selection_convert (GTK_WIDGET (window),
-				       GDK_SELECTION_PRIMARY,
-				       GDK_SELECTION_TYPE_STRING,
-				       GDK_CURRENT_TIME);
+		/* See bug #133633 for why we do it this way */
+
+		/* We need to make sure we know if the tab is destroyed between
+		 * requesting the clipboard contents, and receiving them.
+		 */
+		gpointer *weak_ptr;
+
+		weak_ptr = g_new (gpointer, 1);
+		*weak_ptr = tab;
+		g_object_add_weak_pointer (G_OBJECT (tab), weak_ptr);
+
+		gtk_clipboard_request_text
+			(gtk_widget_get_clipboard (GTK_WIDGET (tab->priv->embed),
+						   GDK_SELECTION_PRIMARY),
+			 (GtkClipboardTextReceivedFunc) clipboard_text_received_cb,
+			 weak_ptr);
 	}
 	/* we didn't handle the event */
 	else
